@@ -1125,12 +1125,17 @@ static int wp_tdmv_software_init(wan_tdmv_t *wan_tdmv)
 					wp->chans[x].name);
 			wp->chans[x].sigcap = 
 				ZT_SIG_EM | ZT_SIG_CLEAR | ZT_SIG_EM_E1 | 
-				ZT_SIG_FXSLS | ZT_SIG_FXSGS | 
-				ZT_SIG_FXSKS | ZT_SIG_FXOLS | 
-				ZT_SIG_FXOGS | ZT_SIG_FXOKS |
-				ZT_SIG_CAS | ZT_SIG_DACS_RBS
+				ZT_SIG_FXSLS | ZT_SIG_FXSGS |  
+				ZT_SIG_FXSKS | ZT_SIG_FXOLS | ZT_SIG_DACS_RBS |
+				ZT_SIG_FXOGS | ZT_SIG_FXOKS | ZT_SIG_CAS 
 #if defined(CONFIG_PRODUCT_WANPIPE_TDM_VOICE_DCHAN) && defined(CONFIG_PRODUCT_WANPIPE_TDM_VOICE_DCHAN_ZAPTEL)
- 				| ZT_SIG_HARDHDLC
+ 				| ZT_SIG_HARDHDLC 
+#endif
+#if defined(ZT_SIG_MTP2)
+				| ZT_SIG_MTP2
+#endif
+#if defined(ZT_SIG_SF)
+				| ZT_SIG_SF
 #endif
 				;
 		}else{
